==> oremo-2.0-b120309.zip: oremo-2.0-b120309/source/globalVar.tcl <==
#!/bin/sh
# the next line restarts using wish \
exec wish "$0" "$@"

# 2.0-b091104
# - s`FbNp̐ݒzǉ

# 2.0-b090720
# - et@Cւ̃pXAexe(starkit)̂Ƃtcl̂ƂƂ̗ɑΉ
# - KChBGM֌W̐ݒǉ
# - gm[AKChBGM֌Wt@CguideBGM/Ɉړ

# 2.0-b090706
# - oremo{̂ɂϐ globalVar.tclɂ܂Ƃ߂

#---------------------------------------------------
# ϐݒ
#
set debug 0
set v(appname) ""
set v(version) ""
if {$::tcl_platform(os) == "Darwin"} {
  set topdir [file join [file dirname [info script]] ../../../..]  ;# for mac
} elseif {[info exists ::starkit::topdir]} {
  set topdir [file dirname [info nameofexecutable]]
} else {
  set topdir [file dirname $argv0]
}
set v(recListFile) "$topdir/reclist.txt"   ;# ^鉹Xgt@C
set v(typeListFile) "$topdir/typelist.txt" ;# ^锭b^CṽXgt@C
set v(saveDir) "$topdir/result"            ;# ^ۑfBNg
set v(yaxisw) 40         ;# c\̉
set v(timeh)  20         ;# \̏c
set v(showWave) 1        ;# 1=g`\, 0=\
set v(waveh)  100        ;# g`pl̏c
set v(wavehbackup) 100   ;# g`\̏cTCỸobNAbvƂ
set v(wavehmin)  50             ;# kۂ̍ŏc
set v(wavepps)  200             ;# pixel/secB
set v(sfont) {Helvetica 8 bold} ;# ڐ\̃tHg
set v(bg) [. cget -bg]
set v(fg) black
set v(wavColor) black
set v(recStatus) 0       ;# 1=^, 0=^ĂȂ
set v(playStatus) 0      ;# 1=Đ, 0=ĐĂȂ
set v(playOnsaStatus) 0  ;# 1=݉Đ, 0=ݍĐĂȂ
set v(recList) {}        ;# ^鉹郊Xg
set v(recSeq) 0          ;# ݎ^̉ԍ
set v(recLab) ""         ;# ݎ^̉
set v(typeList) {""}     ;# ^锭^Cv郊Xg
set v(typeLab) ""        ;# ݎ^̔^Cv
set v(typeSeq) 0         ;# ݎ^̔^Cvԍ
set v(bigFontSize) 24    ;# tHgTCY
set v(fontSize) 18       ;# tHgTCY
set v(smallFontSize) 14  ;# tHgTCY
set v(msg) ""            ;# \tgŉiɕ\郁bZ[W
set v(rec) 1             ;# 1=^OKA0=^s

set v(showSpec) 0        ;# 1=XyNg\, 0=\
set v(spech)    0        ;# XyNg\̏cTCY
set v(spechbackup) 140   ;# XyNg\̏cTCỸobNAbvƂ
set v(spechmin) 100      ;# XyNg\̏cTCY(k̍ŏc)
set v(topfr)    8000     ;# XyNg\̍ōg
set v(cmap)     grey     ;# XyNgzF
set v(contrast) 0        ;# XyNg̃RgXg
set v(brightness) 0      ;# XyNg̖邳
set v(fftlen) 512        ;# FFT
set v(winlen) 128        ;# 
set v(window) Hamming    ;# XyNgo
set v(preemph) 0.97      ;# XyNgõvGt@VX

set v(showpow) 0        ;# 1=p[\, 0=\
set v(powh)    0        ;# p[\̏cTCY
set v(powhmin) 50       ;# p[\̏cTCY(k̍ŏc)
set v(powhbackup) 100   ;# p[\̏cTCỸobNAbvƂ
set power(frameLength) 0.02  ;# p[o[sec]
set power(window)  Hanning    ;# p[ȏ
set power(preemphasis)  0.97  ;# p[õvGt@VX
set power(windowLength)  0.01 ;# p[o[sec]
set power(power) {}           ;# op[lnۑ
set power(powerMax) 0         ;# oʂ̍ől
set power(powerMin) 0         ;# oʂ̍ŏl
set v(powcolor) blue          ;# p[Ȑ̐F

#koko p[^ݒ葋ȂƁB
#set power(uttLow)  28    ;# Ƃ݂ȂU臒l[dB]
#set power(uttHigh) 28    ;# bƂ݂ȂU臒l[dB]
#set power(uttKeep) 5     ;# b̉ʂ̂炬Ƃ݂Ȃ镝臒l[dB]
#set power(uttLengthSec) 0.1  ;# bƂ݂Ȃ鎞Ԓ[sec]
#set power(uttLength) [sec2samp $power(uttLengthSec) $power(frameLength)]  ;# bƂ݂Ȃ鎞Ԓ[sample]
#set power(silLengthSec) 0.0  ;# |[YƂ݂Ȃ鎞Ԓ[sec]
#set power(silLength) [sec2samp $power(silLengthSec) $power(frameLength)]  ;# |[YƂ݂Ȃ鎞Ԓ[sample]
set power(fid) ""                           ;# p[ot@CFID

set v(toneList) {C C# D D# E F F# G G# A A# B} ;# KChXg1oct
set v(sinScaleMin) 2     ;# KChsin̍ŒIN^[u
set v(sinScaleMax) 5     ;# KChsin̍ōIN^[u
set v(sinScale) {}       ;# KChsin̎gXg
set v(sinNote) {}   ;# KChsin̎gɑΉ鉹
set f0(checkVol) 4000    ;# ڍאݒ葋ōĐsin̐Ul
set f0(guideVol) 4000    ;# KChsin̐Ul
set f0(tgtTone) [lindex $v(toneList) 0]  ;# ^[Qbg
set f0(tgtOctave) $v(sinScaleMin)        ;# ^[Qbg̃IN^[u
set f0(tgtFreq) 0                        ;# ^[Qbg̎g
set f0(showToneLine) 0                   ;# 1=ẻF0plɕ\
set  v(toneLineColor) #fffff0            ;# ẻ̐F
set f0(showTgtLine) 0                    ;# 1=^[QbgF0plɕ\
set f0(fid) ""                           ;# F0ot@CFID
set f0(extractedMin) 0                   ;# oF0̍ŏl
set f0(extractedMax) 0                   ;# oF0̍ől

set v(showf0) 0           ;# 1=F0\, 0=\
set v(f0h)    0           ;# F0\̏cTCY
set v(f0hmin) 50          ;# F0\̏cTCY(k̍ŏc)
set v(f0hbackup) 100      ;# F0\̏cTCỸobNAbvƂ
set f0(method) ESPS       ;# F0oASY
set f0(frameLength) 0.01  ;# F0oԊu[sec]
set f0(windowLength) 0.01 ;# F0ȏ[sec]
set f0(max) 800           ;# z肳ōF0
set f0(min) 60            ;# z肳ŒF0
set f0(showMax) 400       ;# F0\͈̔[Hz]
set f0(showMin) 60        ;# F0\͈̔[Hz]
set f0(showMinTone)   [lindex $v(toneList) 0]    ;# F0\͈̔
set f0(showMinOctave) $v(sinScaleMin)            ;# F0\͈̔
set f0(showMaxTone)   [lindex $v(toneList) end]  ;# F0\͈̔
set f0(showMaxOctave) $v(sinScaleMax)            ;# F0\͈̔
set f0(guideTone)   C  ;# 
set f0(guideOctave) 3  ;# 
set f0(guideFreqTmp) 131 
set f0(f0) {}             ;# oF0n
set v(f0color) blue       ;# F0Ȑ̐F
set v(tgtf0color) red     ;# ^[QbgF0̐F
set f0(fixShowRange) 1    ;# 1=F0\XP[Œɂ
set f0(unit) semitone     ;# F0\XP[Bsemitone, Hz

set v(removeDC) 0         ;# 1=^DC
set v(showParam) 1        ;# 1=UTAǓp[^\, 0=\

set v(cWidth) 500                          ;# g`ʃLoX̉
set v(cWidthMin) [expr $v(yaxisw) + 100]   ;# g`ʃLoX̉ŏl
set v(cHeight) [expr $v(waveh) + $v(spech) + $v(powh) + $v(f0h) + $v(timeh)]
                                           ;# g`ʃLoX̏c
set v(winWidth) 640
set v(winWidthMin) $v(cWidthMin)
set v(winWidthMax) [lindex [wm maxsize .] 0]
set v(winHeight) 0

set conState 0  ;# console showȂ1AhideȂ0ł邱Ƃ킷
set scrollWidget ""      ;# ݃}EXXg{bNXɂ΂̃pX

set v(sampleRate) 44100  ;# ̃TvOg[Hz]
set v(paramChanged) 0    ;# 1=p[^ۑ,0=ۑς
set v(search) ""         ;# L[[h

# XyNgzF
set v(grey) " "
set v(color1) {#000 #004 #006 #00A #00F \
               #02F #04F #06F #08F #0AF #0CF #0FF #0FE \
               #0FC #0FA #0F8 #0F6 #0F4 #0F2 #0F0 #2F0 \
               #4F0 #6F0 #8F0 #AF0 #CF0 #FE0 #FC0 #FA0 \
               #F80 #F60 #F40 #F20 #F00}
set v(color2) {#FFF #BBF #77F #33F #00F #07F #0BF #0FF #0FB #0F7 \
               #0F0 #3F0 #7F0 #BF0 #FF0 #FB0 #F70 #F30 #F00}

set startup(readRecList) 1    ;# 1=Nreclist.txtǂ
set startup(readTypeList) 1   ;# 1=Ntypelist.txtǂ

set v(tempo) 120     ;# gm[̃e|(bpm)
set v(tempoMSec) [expr 60000.0 / $v(tempo)]  ;# gm[1̕b
set v(playMetroStatus) 0  ;# 1=݃gm[Đ, 0=ݍĐĂȂ
set v(clickWav) "$topdir/guideBGM/click.wav" ;# gm[̉
set v(bgmFile) "$topdir/guideBGM/F4-100bpm.mp3" ;# ^pBGM
set v(bgmParamFile) "$topdir/guideBGM/F4-100bpm.txt" ;# ^pBGM

array unset bgmParam
set bgmParam(autoRecStatus) 0

# s`FbNp̐ݒ
array unset uttTiming
set uttTiming(clickWav) "$topdir/guideBGM/click.wav"        ;# gm[̉
set uttTiming(tempo) 100                                    ;# `FbNx[BPM]
set uttTimingMSec(tempo) [expr 60000.0 / $uttTiming(tempo)] ;# `FbNx[msec]
set uttTiming(preCount) 3                 ;# ĐOɃgm[炷
set uttTiming(mix) 0.5                    ;# gm[Ɖ̍䗦B
snack::sound uttTiming(clickSnd) -rate $v(sampleRate)

# Ãp[^p̐ݒ
array unset genParam
set genParam(bpm)  100
set genParam(bpmU) bpm
set genParam(S)    0
set genParam(SU)   msec
set genParam(O)    0
set genParam(OU)   msec
set genParam(P)    0
set genParam(PU)   msec
set genParam(C)    0
set genParam(CU)   msec
set genParam(E)    0
set genParam(EU)   msec

# PƉ̃p[^p̐ݒ
array unset estimate
set estimate(S)    1  ;# 1=p[^s
set estimate(E)    1  ;# 1=p[^s
set estimate(C)    1  ;# 1=p[^s

snack::debug $debug
snack::sound snd -channels Mono -rate $v(sampleRate) -debug $debug -fileformat WAV
snack::sound onsa -channels Mono -rate $v(sampleRate)
snack::sound metro
snack::sound bgm    ;# ^KChBGMCg

==> oremo-3.0-b131127.zip: oremo-3.0-b131127/source/globalVar.tcl <==
#!/bin/sh
# the next line restarts using wish \
exec wish "$0" "$@"

# 2.0-b091104
# - s`FbNp̐ݒzǉ

# 2.0-b090720
# - et@Cւ̃pXAexe(starkit)̂Ƃtcl̂ƂƂ̗ɑΉ
# - KChBGM֌W̐ݒǉ
# - gm[AKChBGM֌Wt@CguideBGM/Ɉړ

# 2.0-b090706
# - oremo{̂ɂϐ globalVar.tclɂ܂Ƃ߂

#---------------------------------------------------
# ϐݒ
#
set debug 0
set v(appname) ""
set v(version) ""
if {$::tcl_platform(os) == "Darwin"} {
  set topdir [file join [file dirname [info script]] ../../../..]  ;# for mac
} elseif {[info exists ::starkit::topdir]} {
  set topdir [file dirname [info nameofexecutable]]
} else {
  set topdir [file dirname $argv0]
}
set v(recListFile) "$topdir/reclist.txt"   ;# ^鉹Xgt@C
set v(typeListFile) "$topdir/typelist.txt" ;# ^锭b^CṽXgt@C
set v(saveDir) "$topdir/result"            ;# ^ۑfBNg
set v(paramFile) "$v(saveDir)/oto.ini"     ;# p[^t@C
set v(yaxisw) 40         ;# c\̉
set v(timeh)  20         ;# \̏c
set v(showWave) 1        ;# 1=g`\, 0=\
set v(waveh)  100        ;# g`pl̏c
set v(wavehbackup) 100   ;# g`\̏cTCỸobNAbvƂ
set v(wavehmin)  50             ;# kۂ̍ŏc
set v(wavepps)  200             ;# pixel/secB
set v(waveScale) 32768          ;# g`\c̍őlB0autoscale
set v(sfont) {Helvetica 8 bold} ;# ڐ\̃tHg
set v(bg) [. cget -bg]
set v(fg) black
set v(wavColor) black
set v(recStatus) 0       ;# 1=^, 0=^ĂȂ
set v(playStatus) 0      ;# 1=Đ, 0=ĐĂȂ
set v(playOnsaStatus) 0  ;# 1=݉Đ, 0=ݍĐĂȂ
set v(recList) {}        ;# ^鉹郊Xg
set v(recSeq) 0          ;# ݎ^̉ԍ
set v(recLab) ""         ;# ݎ^̉
set v(typeList) {""}     ;# ^锭^Cv郊Xg
set v(typeLab) ""        ;# ݎ^̔^Cv
set v(typeSeq) 0         ;# ݎ^̔^Cvԍ
set v(bigFontSize) 24    ;# tHgTCY
set v(fontSize) 18       ;# tHgTCY
set v(smallFontSize) 14  ;# tHgTCY
set v(msg) ""            ;# \tgŉiɕ\郁bZ[W
set v(rec) 1             ;# 1=^OKA0=^s
set v(recNow) 0          ;# 1=^(rĂ)A0=^~B
set v(ext) wav           ;# g`t@C̊gq

set v(showSpec) 0        ;# 1=XyNg\, 0=\
set v(spech)    0        ;# XyNg\̏cTCY
set v(spechbackup) 140   ;# XyNg\̏cTCỸobNAbvƂ
set v(spechmin) 100      ;# XyNg\̏cTCY(k̍ŏc)
set v(topfr)    8000     ;# XyNg\̍ōg
set v(cmap)     grey     ;# XyNgzF
set v(contrast) 0        ;# XyNg̃RgXg
set v(brightness) 0      ;# XyNg̖邳
set v(fftlen) 512        ;# FFT
set v(winlen) 128        ;# 
set v(window) Hamming    ;# XyNgo
set v(preemph) 0.97      ;# XyNgõvGt@VX

set v(showpow) 0        ;# 1=p[\, 0=\
set v(powh)    0        ;# p[\̏cTCY
set v(powhmin) 50       ;# p[\̏cTCY(k̍ŏc)
set v(powhbackup) 100   ;# p[\̏cTCỸobNAbvƂ
set power(frameLength) 0.02  ;# p[o[sec]
set power(window)  Hanning    ;# p[ȏ
set power(preemphasis)  0.97  ;# p[õvGt@VX
set power(windowLength)  0.01 ;# p[o[sec]
set power(power) {}           ;# op[lnۑ
set power(powerMax) 0         ;# oʂ̍ől
set power(powerMin) 0         ;# oʂ̍ŏl
set v(powcolor) blue          ;# p[Ȑ̐F

set power(uttLow)  28    ;# Ƃ݂ȂU臒l[dB]
set power(uttHigh) 28    ;# bƂ݂ȂU臒l[dB]
set power(uttKeep) 5     ;# b̉ʂ̂炬Ƃ݂Ȃ镝臒l[dB]
set power(vLow)    40    ;# ꉹƂ݂ȂU臒l[dB]
set power(uttLengthSec) 0.1  ;# bƂ݂Ȃ鎞Ԓ[sec]
set power(uttLength) [sec2samp $power(uttLengthSec) $power(frameLength)]  ;# bƂ݂Ȃ鎞Ԓ[sample]
set power(silLengthSec) 0.0  ;# |[YƂ݂Ȃ鎞Ԓ[sec]
set power(silLength) [sec2samp $power(silLengthSec) $power(frameLength)]  ;# |[YƂ݂Ȃ鎞Ԓ[sample]
set power(fid) ""                           ;# p[ot@CFID

set v(toneList) {C C# D D# E F F# G G# A A# B} ;# KChXg1oct
set v(sinScaleMin) 2     ;# KChsin̍ŒIN^[u
set v(sinScaleMax) 5     ;# KChsin̍ōIN^[u
set v(sinScale) {}       ;# KChsin̎gXg
set v(sinNote) {}   ;# KChsin̎gɑΉ鉹
set f0(checkVol) 4000    ;# ڍאݒ葋ōĐsin̐Ul
set f0(guideVol) 4000    ;# KChsin̐Ul
set f0(tgtTone) [lindex $v(toneList) 0]  ;# ^[Qbg
set f0(tgtOctave) $v(sinScaleMin)        ;# ^[Qbg̃IN^[u
set f0(tgtFreq) 0                        ;# ^[Qbg̎g
set f0(showToneLine) 0                   ;# 1=ẻF0plɕ\
set  v(toneLineColor) #fffff0            ;# ẻ̐F
set f0(showTgtLine) 0                    ;# 1=^[QbgF0plɕ\
set f0(fid) ""                           ;# F0ot@CFID
set f0(extractedMin) 0                   ;# oF0̍ŏl
set f0(extractedMax) 0                   ;# oF0̍ől

set v(showf0) 0           ;# 1=F0\, 0=\
set v(f0h)    0           ;# F0\̏cTCY
set v(f0hmin) 50          ;# F0\̏cTCY(k̍ŏc)
set v(f0hbackup) 100      ;# F0\̏cTCỸobNAbvƂ
set f0(method) ESPS       ;# F0oASY
set f0(frameLength) 0.01  ;# F0oԊu[sec]
set f0(windowLength) 0.01 ;# F0ȏ[sec]
set f0(max) 800           ;# z肳ōF0
set f0(min) 60            ;# z肳ŒF0
set f0(showMax) 400       ;# F0\͈̔[Hz]
set f0(showMin) 60        ;# F0\͈̔[Hz]
set f0(showMinTone)   [lindex $v(toneList) 0]    ;# F0\͈̔
set f0(showMinOctave) $v(sinScaleMin)            ;# F0\͈̔
set f0(showMaxTone)   [lindex $v(toneList) end]  ;# F0\͈̔
set f0(showMaxOctave) $v(sinScaleMax)            ;# F0\͈̔
set f0(guideTone)   C  ;# 
set f0(guideOctave) 3  ;# 
set f0(guideFreqTmp) 131 
set f0(f0) {}             ;# oF0n
set v(f0color) blue       ;# F0Ȑ̐F
set v(tgtf0color) red     ;# ^[QbgF0̐F
set f0(fixShowRange) 1    ;# 1=F0\XP[Œɂ
set f0(unit) semitone     ;# F0\XP[Bsemitone, Hz

set v(removeDC) 0         ;# 1=^DC
set v(showParam) 1        ;# 1=UTAǓp[^\, 0=\

set v(cWidth) 500                          ;# g`ʃLoX̉
set v(cWidthMin) [expr $v(yaxisw) + 100]   ;# g`ʃLoX̉ŏl
set v(cHeight) [expr $v(waveh) + $v(spech) + $v(powh) + $v(f0h) + $v(timeh)]
                                           ;# g`ʃLoX̏c
set v(winWidth) 640
set v(winWidthMin) $v(cWidthMin)
set v(winWidthMax) [lindex [wm maxsize .] 0]
set v(winHeight) 0

set conState 0  ;# console showȂ1AhideȂ0ł邱Ƃ킷
set scrollWidget ""      ;# ݃}EXXg{bNXɂ΂̃pX

set v(sampleRate) 44100  ;# ̃TvOg[Hz]
set v(paramChanged) 0    ;# 1=p[^ۑ,0=ۑς
set v(sdirection) 1 ;# B1=B0=B
set v(sMatch)  full ;# @Bfull=SvAsub=v
set v(keyword) ""   ;# L[[h

# XyNgzF
set v(grey) " "
set v(color1) {#000 #004 #006 #00A #00F \
               #02F #04F #06F #08F #0AF #0CF #0FF #0FE \
               #0FC #0FA #0F8 #0F6 #0F4 #0F2 #0F0 #2F0 \
               #4F0 #6F0 #8F0 #AF0 #CF0 #FE0 #FC0 #FA0 \
               #F80 #F60 #F40 #F20 #F00}
set v(color2) {#FFF #BBF #77F #33F #00F #07F #0BF #0FF #0FB #0F7 \
               #0F0 #3F0 #7F0 #BF0 #FF0 #FB0 #F70 #F30 #F00}

set startup(readRecList) 1    ;# 1=Nreclist.txtǂ
set startup(readTypeList) 1   ;# 1=Ntypelist.txtǂ

set v(tempo) 120     ;# gm[̃e|(bpm)
set v(tempoMSec) [expr 60000.0 / $v(tempo)]  ;# gm[1̕b
set v(playMetroStatus) 0  ;# 1=݃gm[Đ, 0=ݍĐĂȂ
set v(clickWav) "$topdir/guideBGM/click.wav" ;# gm[̉
set v(bgmFile) "$topdir/guideBGM/F4-100bpm.wav" ;# ^pBGM
set v(bgmParamFile) "$topdir/guideBGM/F4-100bpm.txt" ;# ^pBGM
set v(setE) 1   ;# 1=EuNlt@C̑ΒlɂB-1=blank̑Βlɂ

array unset bgmParam
set bgmParam(autoRecStatus) 0

# s`FbNp̐ݒ
array unset uttTiming
set uttTiming(clickWav) "$topdir/guideBGM/click.wav"        ;# gm[̉
set uttTiming(tempo) 100                                    ;# `FbNx[BPM]
set uttTimingMSec(tempo) [expr 60000.0 / $uttTiming(tempo)] ;# `FbNx[msec]
set uttTiming(preCount) 3                 ;# ĐOɃgm[炷
set uttTiming(mix) 0.5                    ;# gm[Ɖ̍䗦B

# Ãp[^p̐ݒ
array unset genParam
set genParam(bpm)  100
set genParam(bpmU) bpm
set genParam(S)    0
set genParam(SU)   msec
set genParam(O)    0
set genParam(OU)   msec
set genParam(P)    0
set genParam(PU)   msec
set genParam(C)    0
set genParam(CU)   msec
set genParam(E)    0
set genParam(EU)   msec
set genParam(autoAdjustRen) 1
set genParam(vLow)      5
set genParam(sRange) 300
set genParam(avePPrev) 0   ;# O̕σp[ۑ
set genParam(autoAdjustRen2)    1
set genParam(autoAdjustRen2Opt) "-s1 200 -s2 10 -l 2048 -p 128 -m 30 -t 1.0 -d tools"
set genParam(autoAdjustRen2Pattern) "     "

# PƉ̃p[^p̐ݒ
array unset estimate
set estimate(S)    1  ;# 1=p[^s
set estimate(E)    1  ;# 1=p[^s
set estimate(C)    1  ;# 1=p[^s
set estimate(P)    1  ;# 1=p[^s
set estimate(O)    1  ;# 1=p[^s
set estimate(minC) 0.001  ;# q̍ŏl(q=0UTAUG[ɂȂ̂h)

array unset paDev
set paDev(devList) {none}     ;# PortAudioł̘^foCXIXg
set paDev(devListMenu) ""     ;# PortAudioł̘^foCXIj[EBWFbg
set paDev(outdevList) {none}  ;# PortAudioł̍ĐfoCXIXg
set paDev(outdevListMenu) ""  ;# PortAudioł̍ĐfoCXIj[EBWFbg
set paDev(recWav) "$topdir/tools/tmp.wav"    ;# oremo-recordero͂wavt@C
set paDev(useRequestRec)  0   ;# WI{^ŎgB1=PortAudio^g(܂gƂ͌Ȃ)B
set paDev(useRequestPlay) 0   ;# WI{^ŎgB1=PortAudioĐg(܂gƂ͌Ȃ)B
set paDev(useRec)         0     ;# 1=PortAudio^gBpaDev(useRequestRec)=1Ŏgp\̂Ƃɂ̂1ɂ
set paDev(usePlay)        0     ;# 1=PortAudioĐgBpaDev(useRequestRec)=1Ŏgp\̂Ƃɂ̂1ɂ
set paDev(sampleRate)   44100 ;# TvOg(Hz)
set paDev(sampleFormat) Int16 ;# `BInt16 Int24 Int32 Float32
set paDev(channel)      1     ;# `l
set paDev(bufferSize)   2048  ;# obt@TCY
array unset paDevFp
set paDevFp(rec)  ""   ;# ^c[Ɖb邽߂fidB""=NĂȂBpaDev()̒ɓĂ͂Ȃ(ioSettings̃p[^obNAbvŕs邽)
set paDevFp(play) ""   ;# Đc[Ɖb邽߂fidB""=NĂȂBpaDev()̒ɓĂ͂Ȃ(ioSettings̃p[^obNAbvŕs邽)
set paDevFp(bgm)  ""   ;# Đc[Ɖb邽߂fidB""=NĂȂBpaDev()̒ɓĂ͂Ȃ(ioSettings̃p[^obNAbvŕs邽)

snack::sound snd   -channels Mono -rate $v(sampleRate) -fileformat WAV -encoding Lin16
snack::sound onsa  -channels Mono -rate $v(sampleRate)
snack::sound metro -channels Mono -rate $v(sampleRate)
snack::sound bgm   -channels Mono -rate $v(sampleRate)
snack::sound uttTiming(clickSnd)  -channels Mono -rate $v(sampleRate)
